@@ -20,7 +20,7 @@ from disco.core.exceptions import GraphQLRequestException
 @pytest.mark.skipif(env.skip, reason=env.reason)
 # TODO: Test with a non-default cluster
 # TODO: Archive jobs on tear-down even if an exception was thrown
-class TestJobsLive(object):
+class TestJobsLive(BaseTest):
 
     def setup_class(self):
         BaseTest.disable_progress_bar()
@@ -62,44 +62,40 @@ class TestJobsLive(object):
             time.sleep(1)
         ''')
 
+        number_of_inputs = 30
+
+        expected_outputs = [self.random_str(prefix=f"output{i}-") for i in range(number_of_inputs)]
+
+        print(f'Uploading {number_of_inputs} input files...')
+
+        input_file_ids = [disco.upload_file(f'input_{i}.txt', expected_outputs[i]) for i in range(number_of_inputs)]
         script_file_id = disco.upload_file('sleep.py', script_content)
         job_name = 'Automation Cancel Job %s' % uuid.uuid4()
         job = disco.Job.create(script_file_id=script_file_id,
+                               input_file_ids=input_file_ids,
                                job_name=job_name)
 
         print(f'Starting job {job.job_id}...')
+
         job.start()
-        job_status = job.wait_for_status(JobStatus.working, interval=10,
-                                         timeout=LIVE_TESTS_JOB_START_WAIT_TIME)
-        assert job_status == JobStatus.working
 
-        print("Waiting for job tasks to start running...")
-        start_time = time.time()
-        timeout_time = start_time + LIVE_TESTS_TASKS_RUNNING_WAIT_TIME
-        while time.time() <= timeout_time:
-            stale_tasks = get_non_running_tasks(job.get_tasks())
-            if len(stale_tasks) == 0:
-                return
-            print("Following tasks haven't started yet: {}".format(stale_tasks))
-            sleep(10)
-        assert len(stale_tasks) == 0
-
-        print(f'Job {job.job_id} started, tasks are running stopping job...')
+        print(f'Job {job.job_id} started, stopping job...')
         job.stop()
 
-        print(f'Waiting for job {job.job_id} to finish...')
-        # TODO: Distinguish between failed or completed and stopped jobs on the
-        #       server side! Currently we can't tell a stopped job from a
-        #       completed job that has a failed task
-        job_status = job.wait_for_status(JobStatus.done, interval=10,
+        print(f'Waiting for job {job.job_id} to stop...')
+        job_status = job.wait_for_status(JobStatus.stopped, interval=10,
                                          timeout=LIVE_TESTS_TIMEOUT_SECONDS)
-        assert job_status == JobStatus.done
+        assert job_status == JobStatus.stopped
 
-        print(f'job {job.job_id} was cancelled!')
+        print(f'job {job.job_id} was stopped!')
 
         tasks = job.get_tasks()
-        assert len(tasks) == 1
-        assert tasks[0].status == TaskStatus.failed.value
+        assert len(tasks) == number_of_inputs
+
+        task_statuses = [task.status for task in tasks]
+        expected_task_statuses = [TaskStatus.stopped.value for _ in tasks]
+
+        assert task_statuses == expected_task_statuses
 
         job.archive()
 
